﻿--[[****************************************************************
	BankItemsFu v1.1
	29 August 2007

	Author: Xinhuan @ US Blackrock Alliance
	****************************************************************
	Description:
		Adds BankItems to FuBar that summarises details of
		chars on the same realm.
	****************************************************************]]


-- Load only if Fubar and BankItems are loaded
if (not IsAddOnLoaded("FuBar") or not IsAddOnLoaded("BankItems")) then
	return;
end

local L = AceLibrary("AceLocale-2.2"):new("FuBar_BankItemsFu");
local Tablet = AceLibrary("Tablet-2.0");
local Abacus = AceLibrary("Abacus-2.0");
local Dewdrop = AceLibrary("Dewdrop-2.0");

BankItemsFu = AceLibrary("AceAddon-2.0"):new("FuBarPlugin-2.0", "AceDB-2.0", "AceEvent-2.0");
local BankItemsFu = BankItemsFu;
BankItemsFu.defaultPosition = 'RIGHT';
BankItemsFu.hasIcon = "Interface\\Icons\\INV_Misc_Bag_10_Blue";
BankItemsFu.canHideText = true;
BankItemsFu.hasNoColor = true;
BankItemsFu.defaultMinimapPosition = 345;
BankItemsFu.title = "BankItemsFu";
BankItemsFu.version = "v20002";
BankItemsFu.date = "2007-01-04";

BankItemsFu:RegisterDB("BankItemsFuDB");
BankItemsFu:RegisterDefaults('profile', {
	showMoney = true,
	showBags = true,
});

L:RegisterTranslations("enUS", function() return {
	["|cffeda55fClick|r to toggle BankItems display"] = true,
	["Characters"] = true,
	["Slots"] = true,
	["Money"] = true,
	["Total"] = true,
	["Show Minimap Button"] = true,
	["Show the BankItems Minimap Button"] = true,
	["Show/Hide BankItems window"] = true,
	["Show/Hide the BankItems window"] = true,
	["Show Money"] = true,
	["Show Bags"] = true,
	["Purge"] = true,
	["Delete stored data of..."] = true,
	["Data of '%s of %s' deleted."] = true,
} end);

L:RegisterTranslations("deDE", function() return {
	["|cffeda55fClick|r to toggle BankItems display"] = "|cffeda55fKlicken|r um BankItems ein-/auszublenden",
	["Characters"] = "Charakter",
	["Slots"] = "Taschenplätze",
	["Money"] = "Geld",
	["Total"] = "Gesamt",
	["Show Minimap Button"] = "Minimap Button ein-/ausblenden",
	["Show the BankItems Minimap Button"] = "Minimap Button ein-/ausblenden.",
	["Show/Hide BankItems window"] = "BankItems ein-/ausblenden",
	["Show/Hide the BankItems window"] = "BankItems Hauptfenster ein-/ausblenden.",
	["Show Money"] = "Zeige Geld",
	["Show Bags"] = "Zeige Taschenplätze",
	["Purge"] = "Löschen",
	["Delete stored data of..."] = "Lösche gespeicherte Daten von...",
	["Data of '%s of %s' deleted."] = "Daten von '%s von %s' gelöscht.",
} end);

function BankItemsFu:OnInitialize()
	self.name = "BankItemsFu";
	self.hiddenframe = CreateFrame("Frame");
end

local function delay2frames(self, elapsed)
	self.delay = self.delay + 1;
	if (self.delay == 2) then
		BankItemsFu:UpdateText();
		BankItemsFu:UpdateTooltip();
		self:SetScript("OnUpdate", nil);
	end
end

function BankItemsFu:PrepareUpdate()
	self.hiddenframe:SetScript("OnUpdate", delay2frames);
	self.hiddenframe.delay = 0;
end

function BankItemsFu:OnEnable()
	self:RegisterEvent("PLAYER_MONEY", "PrepareUpdate");
	self:RegisterEvent("BAG_UPDATE", "PrepareUpdate");
	self:RegisterEvent("BANKFRAME_OPENED", "PrepareUpdate");
	self:RegisterEvent("PLAYERBANKSLOTS_CHANGED", "PrepareUpdate");
	self:RegisterEvent("PLAYERBANKBAGSLOTS_CHANGED", "PrepareUpdate");
	self:PrepareUpdate();
end

function BankItemsFu:OnDisable()
	self:UnregisterEvent("PLAYER_MONEY");
	self:UnregisterEvent("BAG_UPDATE");
	self:UnregisterEvent("BANKFRAME_OPENED");
	self:UnregisterEvent("PLAYERBANKSLOTS_CHANGED");
	self:UnregisterEvent("PLAYERBANKBAGSLOTS_CHANGED");
end

function BankItemsFu:OnMenuRequest(level, value)
	if (level == 1) then
		Dewdrop:AddLine(
			'text', L["Show/Hide BankItems window"],
			'tooltipTitle', L["Show/Hide BankItems window"],
			'tooltipText', L["Show/Hide the BankItems window"],
			'func', function()
				BankItems_SlashHandler();
			end
		)

		Dewdrop:AddLine(
			'text', L["Show Minimap Button"],
			'tooltipTitle', L["Show Minimap Button"],
			'tooltipText', L["Show the BankItems Minimap Button"],
			'func', function()
				BankItems_Save.ButtonShown = not BankItems_Save.ButtonShown;
				BankItems_MinimapButton_Init();
			end,
			'checked', BankItems_Save.ButtonShown
		)

		Dewdrop:AddLine();
		Dewdrop:AddLine(
			'text', L["Purge"],
			'tooltipTitle', L["Purge"],
			'tooltipText', L["Delete stored data of..."],
			'hasArrow', true,
			'value', "purge"
		);
		Dewdrop:AddLine(
			'text', L["Show Money"],
			'tooltipTitle', L["Show Money"],
			'tooltipText', L["Show Money"],
			'func', function()
				self.db.profile.showMoney = not self.db.profile.showMoney;
				self:UpdateText();
			end,
			'checked', self.db.profile.showMoney
		)
		Dewdrop:AddLine(
			'text', L["Show Bags"],
			'tooltipTitle', L["Show Bags"],
			'tooltipText', L["Show Bags"],
			'func', function()
				self.db.profile.showBags = not self.db.profile.showBags;
				self:UpdateText();
			end,
			'checked', self.db.profile.showBags
		)


	elseif (level == 2) then
		if (value == "purge") then
			local realm = "|"..BankItems_Trim(GetCVar("realmName"));
			local cname;

			for key, value in pairs(BankItems_Save) do
				if (type(value) == "table") then
					cname = string.gsub(key, realm, "");
					if (string.find(key, realm)) then
						if (cname ~= UnitName("player")) then
							Dewdrop:AddLine(
								'text', cname,
								'tooltipTitle', L["Purge"],
								'tooltipText', "... "..cname,
								'arg1', self,
								'arg2', cname,
								'func', self.DelPlayer,
								'closeWhenClicked', true
							);
						else
							Dewdrop:AddLine(
								'text', cname,
								'tooltipTitle', L["Purge"],
								'tooltipText', cname,
								'disabled', true
							);
						end
					end
				end
			end

		end
	end
end

function BankItemsFu:OnTextUpdate()
	local text = "";

	if (self.db.profile.showMoney) then
		text = text..Abacus:FormatMoneyFull(GetMoney(), true);
	end

	if (self.db.profile.showBags) then
		local value = BankItems_Save[UnitName("player").."|"..BankItems_Trim(GetCVar("realmName"))];
		local space = 0;
		local totspace = 28;
		for num = 1, 28 do
			if (value[num]) then
				space = space + 1;
			end
		end
		for bagNum = 0, 11 do
			if (value["Bag"..bagNum]) then
				totspace = totspace + value["Bag"..bagNum].size;
				for bagItem = 1, value["Bag"..bagNum].size do
					if (value["Bag"..bagNum][bagItem]) then
						space = space + 1;
					end
				end
			end
		end
		if (not value["Bag0"]) then
			totspace = totspace + GetContainerNumSlots(0);
		end

		if self.db.profile.showMoney then
			text = text.." ";
		end
		text = text.."|cFFFFFFFF"..space.."/"..totspace.."|r";
	end

	if (not self.db.profile.showMoney and not self.db.profile.showBags) then
		self:SetText(self.name);
	else
		self:SetText(text);
	end

end

function BankItemsFu:OnTooltipUpdate()
	local cat = Tablet:AddCategory(
		'columns', 3,
		'child_textR', 1,
		'child_textG', 1,
		'child_textB', 0,
		'child_text2R', 1,
		'child_text2G', 1,
		'child_text2B', 1,
		'text', L["Characters"],
		'text2', L["Slots"],
		'text3', L["Money"]
	);

	local total = 0;
	local gspace = 0;
	local gtotspace = 0;
	local realm = "|"..BankItems_Trim(GetCVar("realmName"));

	for key, value in pairs(BankItems_Save) do
		if (type(value) == "table") then
			if (string.find(key, realm, 1, true) and value.money) then
				local space = 0;
				local totspace = 28;

				for num = 1, 28 do
					if (value[num]) then
						space = space + 1;
					end
				end
				for bagNum = 0, 11 do
					if (value["Bag"..bagNum]) then
						totspace = totspace + value["Bag"..bagNum].size;
						for bagItem = 1, value["Bag"..bagNum].size do
							if (value["Bag"..bagNum][bagItem]) then
								space = space + 1;
							end
						end
					end
				end
				if (not value["Bag0"]) then
					totspace = totspace + GetContainerNumSlots(0);
				end

				cat:AddLine(
					'text', string.gsub(key, realm, ""),
					'text2', space.."/"..totspace,
					'text3', Abacus:FormatMoneyFull(value.money, true)
				);

				total = total + value.money;
				gspace = gspace + space;
				gtotspace = gtotspace + totspace;
			end
		end
	end

	cat:AddLine(
		'text', " ",
		'text2', " ",
		'text3', " "
	)
	cat:AddLine(
		'text', L["Total"],
		'text2', gspace.."/"..gtotspace,
		'text3', Abacus:FormatMoneyFull(total, true)
	)

	Tablet:SetHint(L["|cffeda55fClick|r to toggle BankItems display"])
end

function BankItemsFu:OnClick()
	BankItems_SlashHandler();
end

function BankItemsFu:DelPlayer(name)
	BankItems_DelPlayer(name.."|"..BankItems_Trim(GetCVar("realmName")));
	BankItems_Chat(format(L["Data of '%s of %s' deleted."],name,BankItems_Trim(GetCVar("realmName"))));
end
